==> miktex-2.9.7050.tar.xz: miktex-2.9.7050/Libraries/3rd/log4cxx/source/src/main/cpp/manualtriggeringpolicy.cpp <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <log4cxx/rolling/manualtriggeringpolicy.h>
#include <log4cxx/helpers/stringhelper.h>
#include <log4cxx/helpers/optionconverter.h>

using namespace log4cxx;
using namespace log4cxx::rolling;
using namespace log4cxx::helpers;

IMPLEMENT_LOG4CXX_OBJECT(ManualTriggeringPolicy)

ManualTriggeringPolicy::ManualTriggeringPolicy() {
}

bool ManualTriggeringPolicy::isTriggeringEvent(Appender* /* appender */,
          const log4cxx::spi::LoggingEventPtr& /* event */,
          const LogString& /* file */,
          size_t /* fileLength */ ) {
  return false;
}

void ManualTriggeringPolicy::activateOptions(Pool& /* p */ ) {
}

void ManualTriggeringPolicy::setOption(const LogString& /* option */ , const LogString& /* value */ ) {
}

==> miktex-23.4.tar.xz: miktex-23.4/Libraries/3rd/log4cxx/source/src/main/cpp/manualtriggeringpolicy.cpp <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <log4cxx/rolling/manualtriggeringpolicy.h>
#include <log4cxx/helpers/stringhelper.h>
#include <log4cxx/helpers/optionconverter.h>

using namespace log4cxx;
using namespace log4cxx::rolling;
using namespace log4cxx::helpers;

IMPLEMENT_LOG4CXX_OBJECT(ManualTriggeringPolicy)

ManualTriggeringPolicy::ManualTriggeringPolicy()
{
}

bool ManualTriggeringPolicy::isTriggeringEvent(Appender* /* appender */,
	const log4cxx::spi::LoggingEventPtr& /* event */,
	const LogString& /* file */,
	size_t /* fileLength */ )
{
	return false;
}

void ManualTriggeringPolicy::activateOptions(Pool& /* p */ )
{
}

void ManualTriggeringPolicy::setOption(const LogString& /* option */, const LogString& /* value */ )
{
}
